@@ -208,6 +208,58 @@ class GetLatestTinderbox(object):
     else:
       raise NotFoundException("No logs found", url)
 
+  @classmethod
+  def all_logs(cls, branches=('mozilla-central',), platforms=None, debug=(False, True), tests=None, timestamp=0, logger=None):
+    """yield all the tests currently found"""
+
+    # determine the platforms
+    if not platforms:
+      platforms = globals()['platforms'][:]
+
+    for branch in branches:
+      for _debug in debug:
+        for platform in platforms:
+
+          # get your scraper
+          latest = cls(branch=branch, platform=platform, debug=_debug)
+
+          # find the builds
+          try:
+            builds = latest.builds(timestamp=timestamp)
+          except NotFoundException:
+            if logger:
+              logger.warn('No builds found for %s %s %s' % (branch,
+                                                            platform,
+                                                            _debug))
+            continue
+
+          for build, url in builds.items():
+
+            # find the logs
+            try:
+              logs = latest.logs(url)
+            except NotFoundException:
+              if logger:
+                logger.warn('No logs found at %s' % url)
+              continue
+
+            # determine which test logs to download
+            if tests:
+              logs = dict([(test, value) for test.value in logs.items()
+                           if test in tests])
+
+            if logger:
+              logger.info('%d logs' % len(logs))
+
+            # yield the test URL and metadata
+            for test, value in logs.items():
+              yield value, dict(branch=branch,
+                                platform=platform,
+                                debug=debug,
+                                timestamp=build,
+                                test=test)
+              
+
 def main(args=sys.argv[1:]):
 
   # parse options
@@ -235,6 +287,9 @@ def main(args=sys.argv[1:]):
                     help='list test logs')
   parser.add_option('--log', '-l', dest='log',
                     help='print the URL of a specific log file')
+  parser.add_option('--all-logs', dest='print_all_logs',
+                    action='store_true', default=False,
+                    help='print all logs in the world')
   parser.add_option('--url', '-u', dest='url',
                     help="get builds from a specific url")
   parser.add_option('--latest', dest='latest', action='store_true', default=False,
@@ -260,6 +315,13 @@ def main(args=sys.argv[1:]):
   if options.start:
     options.start = str2ssepoch(options.start)
 
+  # print out all logs in the whole multiverse
+  if options.print_all_logs:
+    all_logs = GetLatestTinderbox.all_logs()
+    for log in all_logs:
+      print log[0]
+    return
+      
   # instantiate class
   latest_tinderbox = GetLatestTinderbox(options.product, options.platform, options.debug)
 
